{% extends "admin/change_form.html" %}

{% load i18n %}
  
{% block extrahead %}{{ block.super }}
<style type="text/css">
    .dynamic-inline .vTextField {width:100px !important;}
</style>
{% endblock %}

{% block object-tools %}
{% if change %}{% if not is_popup %}
  <ul class="object-tools">
  <li><a href="{% url admin:form_export object_id %}">{% trans "Export entries" %}</a></li>
  <li><a href="history/" class="historylink">{% trans "History" %}</a></li>
  {% if has_absolute_url %}<li><a href="../../../r/{{ content_type_id }}/{{ object_id }}/" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
  </ul>
{% endif %}{% endif %}
{% endblock %}
