{% extends "admin/base_site.html" %}

<!-- LOADING -->
{% load i18n mezzanine_tags %}

{% block extrahead %}
{{ block.super }}
{% endblock %}

<!-- STYLES & SCRIPTS -->
{% block stylesheets %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% load adminmedia %}{% admin_media_prefix %}css/dashboard.css" />
    <style type="text/css">
        #quick-blog input, textarea {width:400px;}
        .default {width:auto !important;}
        .module {margin-bottom:10px !important;}
        .module ul {list-style-type:none !important; margin-left:0px;}
        .mini {font-size:.9em;}
    </style>
	
	<!--[if IE 7]>
		<style>
			.dashboard #content { padding-top: 80px; }
		</style>
	<![endif]-->

{% endblock %}
{% block javascripts %}
    {{ block.super }}
    <script type="text/javascript" src="{% admin_media_prefix %}js/admin/CollapsibleGroup.js"></script>
{% endblock %}

<!-- COLTYPE/BODYCLASS -->
{% block coltype %}colMS{% endblock %}
{% block bodyclass %}dashboard{% endblock %}

<!-- BREADCRUMBS -->
{% block breadcrumbs %}<div class="breadcrumbs">{% trans "Home" %}</div>{% endblock %}

{% block content_title %}<h1>{% trans "Dashboard" %}</h1>{% endblock %}

<!-- CONTENT -->
{% block content %}
<div id="content-main">
    {% dashboard_column 0 %}
</div>
{% endblock %}

<!-- SIDEBAR -->
{% block sidebar %}
<div id="content-related" style="float:right; margin:0 -38em 0 10px;">
    {% dashboard_column 2 %}
</div>

{% block extendedsidebar %}
<div id="content-related" style="float:right; margin-right:-19em;">
    {% dashboard_column 1 %}
</div>
{% endblock %}

{% endblock %}
