{% load i18n %}

<h3>{% trans "Search" %}</h3>
<form method="get" action="{% url search %}" id="search">
    <input type="text" name="q" value="{{ request.REQUEST.q }}" />
    <input type="submit" value="{% trans "Go" %}" class="button" />
</form>
<p class="help">
    {% trans "Use "%} "{% trans "quotes" %}" {% trans " for exact phrases, + to make a word or phrase required, and - to exclude a word or phrase." %}"
</p>

