{% load pages_tags i18n %}
<html>
<head>

    <meta http-equiv="Content-type" content="text/html; charset=utf-8" /> 
    <meta name="keywords" content="{% block meta_keywords %}{% endblock %}" /> 
    <meta name="description" content="{% block meta_description %}{% endblock %}" /> 
    <title>{% block meta_title %}{% endblock %}{% if settings.SITE_TITLE %} | {{ settings.SITE_TITLE }}{% endif %}</title>

    <link rel="alternate" type="application/rss+xml" title="RSS" 
        href="{% url blog_post_feed "rss" %}" />
    <link rel="alternate" type="application/atom+xml" title="Atom"  
        href="{% url blog_post_feed "atom" %}" />

    <link rel="stylesheet" href="{{ MEDIA_URL }}css/960.css" type="text/css" />
    <link rel="stylesheet" href="{{ MEDIA_URL }}css/reset.css" type="text/css" />
    <link rel="stylesheet" href="{{ MEDIA_URL }}css/global.css" type="text/css" />
    {% block extra_head %}{% endblock %}

</head>
<body id="{% block body_id %}{% endblock %}">

{% if settings.SITE_TITLE or settings.SITE_TAGLINE %}
<div id="grid-header">
    {% if settings.SITE_TITLE %}
    <h1>{{ settings.SITE_TITLE }}</h1>
    {% endif %}
    {% if settings.SITE_TAGLINE %}
    <h2>{{ settings.SITE_TAGLINE }}</h2>
    {% endif %}
</div>
{% endif %}

<div id="grid-top">
    {% page_menu "pages/menus/primary.html" %}
</div>

<div class="container_12 clearfix">

    <div id="grid-left" class="grid_3 grid">
        {% page_menu "pages/menus/tree.html" %}
    </div>

    <div id="grid-middle" class="grid_6 grid">
        <div class="gutter">
            <h1>{% block title %}{% endblock %}</h1>
            <div id="breadcrumb-menu">
                {% block breadcrumb_menu %}
                    {% page_menu "pages/menus/breadcrumb.html" %}
                {% endblock %}
            </div>
            {% block main %}{% endblock %}
        </div>
    </div>

    <div id="grid-right" class="grid_3 grid">
        {% include "includes/search.html" %}
        {% block right_panel %}
            {% include "twitter/tweets.html" %}
        {% endblock %}
        <p class="mezzanine">
            {% trans "Powered by" %} 
            <a href="http://mezzanine.jupo.org">Mezzanine</a><br />
            <a href="{% url set_device "mobile" %}?next={{ request.path }}">
                {% trans "View Mobile Site." %}
            </a>
        </p>
    </div>

</div>

<div id="grid-bottom">
    <div class="container_12 clearfix">
        <div class="grid_6 push_3 grid">
            {% page_menu "pages/menus/footer.html" %}
        </div>
    </div>
</div>

{% include "includes/footer_scripts.html" %}

</body>
</html>

